:py:mod:`conf`
==============

.. py:module:: conf


Module Contents
---------------

.. py:data:: project
   :annotation: = Heron

   

.. py:data:: copyright
   :annotation: = 2022, George Dimitriadis

   

.. py:data:: author
   :annotation: = George Dimitriadis

   

.. py:data:: extensions
   :annotation: = []

   

.. py:data:: autoapi_type
   :annotation: = python

   

.. py:data:: autoapi_dirs
   :annotation: = ['../../../Heron']

   

.. py:data:: autoapi_add_toctree_entry
   :annotation: = False

   

.. py:data:: autoapi_root
   :annotation: = autoapi

   

.. py:data:: autoapi_keep_files
   :annotation: = True

   

.. py:data:: extensions
   :annotation: = ['sphinx.ext.autodoc', 'autoapi.extension']

   

.. py:data:: autodoc_typehints
   :annotation: = description

   

.. py:data:: templates_path
   :annotation: = ['_templates']

   

.. py:data:: exclude_patterns
   :annotation: = []

   

.. py:data:: html_theme
   :annotation: = sphinx_rtd_theme

   

.. py:data:: html_static_path
   :annotation: = ['_static']

   

